"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const aws_cdk_lib_1 = require("aws-cdk-lib");
const aws_lambda_1 = require("aws-cdk-lib/aws-lambda");
exports.default = (scope) => {
    const flags = aws_cdk_lib_1.FeatureFlags.of(scope);
    const useLatestRuntimeVersion = flags.isEnabled("@aws-cdk/aws-lambda-nodejs:useLatestRuntimeVersion");
    if (useLatestRuntimeVersion === true && "NODEJS_LATEST" in aws_lambda_1.Runtime) {
        // eslint-disable-next-line @typescript-eslint/no-unnecessary-type-assertion
        return aws_lambda_1.Runtime.NODEJS_LATEST;
    }
    // CDK v2.109.0 support Node.js 20
    if ("NODEJS_20_X" in aws_lambda_1.Runtime) {
        // eslint-disable-next-line @typescript-eslint/no-unnecessary-type-assertion
        return aws_lambda_1.Runtime.NODEJS_20_X;
    }
    // CDK v2.51.0 support Node.js 18
    if ("NODEJS_18_X" in aws_lambda_1.Runtime) {
        // eslint-disable-next-line @typescript-eslint/no-unnecessary-type-assertion
        return aws_lambda_1.Runtime.NODEJS_18_X;
    }
    // CDK v2.24.0 support Node.js 16
    if ("NODEJS_16_X" in aws_lambda_1.Runtime) {
        // eslint-disable-next-line @typescript-eslint/no-unnecessary-type-assertion
        return aws_lambda_1.Runtime.NODEJS_16_X;
    }
    throw new Error("Failed to determine a default Runtime version");
};
